# -*- coding: utf-8 -*-
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models, api, _
from odoo.tools.misc import formatLang


class AccountInvoice(models.Model):
    _inherit = "account.invoice"

    """
    Inheritance of the unlink function to set the tasks linked to the invoice
    lines to be deleted as tasks to be re-invoiced.
    """
    @api.multi
    def unlink(self):
        task_ids = self.env['project.task']
        for sel in self:
            for line in sel.invoice_line_ids:
                if line.task_id:
                    task_ids += line.task_id
        res = super(AccountInvoice, self).unlink()
        if res:
            for task in task_ids:
                task.stage_id = self.env['project.task.type'].search([
                    ('name', '=', 'To Invoice')
                ])
        return res

    """
    Function to check if the VAT taxes are correctly set
    """
    def check_vat_taxes_portal(self):
        total = 0
        for line in self.tax_line_ids:
            if line.account_id.code[:3] != '475':
                total += line.amount
        return total == 0

    """
    Function to get the taxes of the portal user's invoice.
    """
    def get_taxes_portal(self):
        res = {}
        currency = self.currency_id or self.company_id.currency_id
        for line in self.tax_line_ids:
            tax_str = ''
            if line.account_id.code[:3] == '475':
                tax_str += _('IRPF (') + str(abs(line.tax_id.amount)) + '%)'
            else:
                tax_str += _('VAT (') + str(line.tax_id.amount) + '%)'
            res.setdefault(tax_str, 0.0)
            res[tax_str] += line.amount
        res = sorted(res.items(), reverse=True)
        res = [(
            r[0], r[1],
            formatLang(self.with_context(lang=self.partner_id.lang).env,
                       r[1], currency_obj=currency)
        ) for r in res]
        taxes = []
        if self.check_vat_taxes_portal():
            for tax in res:
                if 'VAT' not in tax[0]:
                    taxes.append(tax)
        else:
            taxes = res
        return taxes
