# -*- coding: utf-8 -*-
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models, fields, _
from odoo.exceptions import ValidationError


class ConfirmPartnerWebsite(models.Model):
    _name = "confirm.partner.website"

    name = fields.Char(
        string=_('Name'),
        related='partner_id.name',
    )
    partner_id = fields.Many2one(
        string=_('Partner ID'),
        comodel_name='res.partner'
    )
    active = fields.Boolean(
        default=True
    )
    bank_id = fields.Many2one(
        string=_('New Bank'),
        comodel_name='res.bank',
    )
    old_bank_id = fields.Many2one(
        string=_('Old Bank'),
        comodel_name='res.bank',
    )
    state = fields.Selection(
        string=_('State'),
        default='open',
        selection=[('open', 'Open'), ('refuse', 'Refuse'), ('close', 'Close')]
    )

    # OLD FIELDS
    old_name = fields.Char(
        string=_('Old Name'),
    )
    old_email = fields.Char(
        string=_('Old Email'),
    )
    old_phone = fields.Char(
        string=_('Old Phone'),
    )
    old_mobile = fields.Char(
        string=_('Old Moblie'),
    )
    old_company = fields.Char(
        string=_('Old Company Name'),
    )
    old_vat = fields.Char(
        string=_('Old TIN-VAT Number'),
    )
    old_street = fields.Char(
        string=_('Old Street'),
    )
    old_street2 = fields.Char(
        string=_('Old Street 2'),
    )
    old_city = fields.Char(
        string=_('Old City'),
    )
    old_zip = fields.Char(
        string=_('Old Zip / Postal Code'),
    )
    old_country_id = fields.Many2one(
        string=_('Old Country'),
        comodel_name='res.country',
    )
    old_state_id = fields.Many2one(
        string=_('Old State / Province'),
        comodel_name='res.country.state',
    )
    old_bank = fields.Char(
        string=_('Old Bank Account'),
    )
    old_bank_name = fields.Char(
        string=_('Old Bank Name'),
    )
    old_bank_country_id = fields.Many2one(
        string=_('Old Bank Country'),
        comodel_name='res.country',
    )
    old_swift = fields.Char(
        string=_('Old Swift'),
    )
    old_aba = fields.Char(
        string=_('Old ABA'),
    )
    old_fed_wire = fields.Char(
        string=_('Old FED wire'),
    )
    old_beneficiary = fields.Char(
        string=_('Old Beneficiary'),
    )
    old_paypal_email = fields.Char(
        string=_('Old Paypal Email'),
    )
    old_comment_invoice = fields.Char(
        string=_('Old Invoice Comment'),
    )

    # NEW FIELDS
    new_name = fields.Char(
        string=_('New Name'),
    )
    new_email = fields.Char(
        string=_('New Email'),
    )
    new_phone = fields.Char(
        string=_('New Phone'),
    )
    new_mobile = fields.Char(
        string=_('New Mobile'),
    )
    new_company = fields.Char(
        string=_('New Company Name'),
    )
    new_vat = fields.Char(
        string=_('New TIN-VAT Number'),
    )
    new_street = fields.Char(
        string=_('New Street'),
    )
    new_street2 = fields.Char(
        string=_('New Street 2'),
    )
    new_city = fields.Char(
        string=_('New City'),
    )
    new_zip = fields.Char(
        string=_('New Zip / Postal Code'),
    )
    new_country_id = fields.Many2one(
        string=_('New Country'),
        comodel_name='res.country',
    )
    new_state_id = fields.Many2one(
        string=_('New State / Province'),
        comodel_name='res.country.state',
    )
    new_bank = fields.Char(
        string=_('New Bank Account'),
    )
    new_bank_name = fields.Char(
        string=_('New Bank Name'),
    )
    new_bank_country_id = fields.Many2one(
        string=_('New Bank Country'),
        comodel_name='res.country',
    )
    new_swift = fields.Char(
        string=_('New Swift'),
    )
    new_aba = fields.Char(
        string=_('New ABA'),
    )
    new_fed_wire = fields.Char(
        string=_('New FED wire'),
    )
    new_beneficiary = fields.Char(
        string=_('New Beneficiary'),
    )
    new_paypal_email = fields.Char(
        string=_('New Paypal Email'),
    )
    new_comment_invoice = fields.Char(
        string=_('New Invoice Comment'),
    )

    # COMPARE FIELDS
    partner_name = fields.Boolean(
        string=_('Name has not changed'),
    )
    email = fields.Boolean(
        string=_('Email has not changed'),
    )
    phone = fields.Boolean(
        string=_('Phone has not changed'),
    )
    mobile = fields.Boolean(
        string=_('Mobile has not changed'),
    )
    company = fields.Boolean(
        string=_('Company Name has not changed'),
    )
    vat = fields.Boolean(
        string=_('VAT Number has not changed'),
    )
    street = fields.Boolean(
        string=_('Street has not changed'),
    )
    street2 = fields.Boolean(
        string=_('Street 2 has not changed'),
    )
    city = fields.Boolean(
        string=_('City has not changed'),
    )
    zip = fields.Boolean(
        string=_('Zip / Postal Code has not changed'),
    )
    country_id = fields.Boolean(
        string=_('Country has not changed'),
    )
    state_id = fields.Boolean(
        string=_('State / Province has not changed'),
    )
    bank = fields.Boolean(
        string=_('Bank Account has not changed'),
    )
    bank_name = fields.Boolean(
        string=_('Bank Name has not changed'),
    )
    bank_country_id = fields.Boolean(
        string=_('Bank Country has not changed'),
    )
    swift = fields.Boolean(
        string=_('Swift has not changed'),
    )
    aba = fields.Boolean(
        string=_('ABA has not changed'),
    )
    fed_wire = fields.Boolean(
        string=_('FED wire has not changed'),
    )
    beneficiary = fields.Boolean(
        string=_('Beneficiary has not changed'),
    )
    paypal_email = fields.Boolean(
        string=_('Paypal Email has not changed'),
    )
    comment_invoice = fields.Boolean(
        string=_('Invoice Comment has not changed'),
    )

    def _test_checks(self, new_dict):
        for k, v in new_dict.items():
            if 'new' in k:
                new_f = k.replace('new', 'old')
                check_f = new_f.replace('old_', '')
                if 'vat' or 'zip' in k:
                    if self[k] == '':
                        self[k] = False
                self[check_f] = self[k] == self[new_f]

    def refuse_partner(self):
        self.state = 'refuse'

    def open_partner(self):
        self.state = 'open'

    def update_partner(self):
        if (self.new_bank_name and self.new_swift and
                not self.bank_id):
            raise ValidationError(
               _("It is necessary to fill in the bank field.")
            )
        elif (self.new_bank_name and self.new_swift and self.bank_id and
                not self.bank_id.bic):
            raise ValidationError(
               _("It is necessary to fill in the bic field in the bank.")
            )
        elif (self.new_bank_name and self.new_swift and
                (self.new_swift.lower() != self.bank_id.bic.lower())):
            raise ValidationError(
               _("The bank swift doesn't match with the new swift.")
            )
        else:
            partner_vals = {}
            bank_vals = {}
            if not self.partner_name:
                partner_vals['name'] = self.new_name
            if not self.email:
                partner_vals['email'] = self.new_email
            if not self.phone:
                partner_vals['phone'] = self.new_phone
            if not self.mobile:
                partner_vals['mobile'] = self.new_mobile
            if not self.company:
                partner_vals['company_name'] = self.new_company
            if not self.vat:
                partner_vals['vat'] = self.new_vat
            if not self.street:
                partner_vals['street'] = self.new_street
            if not self.street2:
                partner_vals['street2'] = self.new_street2
            if not self.city:
                partner_vals['city'] = self.new_city
            if not self.zip:
                partner_vals['zip'] = self.new_zip
            if not self.country_id:
                partner_vals['country_id'] = self.new_country_id.id
            if not self.state_id:
                partner_vals['state_id'] = self.new_state_id.id
            if not self.paypal_email:
                partner_vals['paypal_email'] = self.new_paypal_email
            if not self.comment_invoice:
                partner_vals[
                    'comment_invoice_portal'] =\
                     self.new_comment_invoice
            if not self.bank:
                partner_vals['bank_account'] = self.new_bank
                bank_vals['acc_number'] = self.new_bank
            if not self.bank_country_id:
                bank_vals['acc_country_id'] =\
                 self.new_bank_country_id.id
            if self.bank_id:
                bank_vals['bank_id'] = self.bank_id.id
            if not self.beneficiary:
                bank_vals['beneficiary'] = self.new_beneficiary
            if not self.aba:
                bank_vals['aba'] = self.new_aba
            if not self.fed_wire:
                bank_vals['fed_wire'] = self.new_fed_wire

            if self.partner_id.bank_ids:
                self.partner_id.bank_ids[0].write(bank_vals)
            elif bank_vals.get('acc_number', False):
                bank_vals['partner_id'] = self.partner_id.id
                self.partner_id.bank_ids.create(bank_vals)

        self.partner_id.write(partner_vals)

        self.state = 'close'
