# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from odoo import models, fields, api, _
from odoo.exceptions import ValidationError


class ProjectTask(models.Model):
    _inherit = 'project.task'

    language_source = fields.Char(
        string=_('Source Language'),
        copy=True,
    )
    language_dest = fields.Char(
        string=_('Target Language'),
        copy=True,
    )
    price_hour = fields.Float(
        string="Price per hour",
    )
    dedicated_hours = fields.Float(
        string="Dedicated hours"
    )

    @api.constrains('stage_id')
    def check_task_stage(self):
        for sel in self:
            if sel.stage_id.name == 'Refused' and sel.user_id:
                sel.user_id = False
            if sel.stage_id.name == 'Sent':
                if not sel.user_id:
                    raise ValidationError(
                        _('"Assigned to" must be defined!'))
                body = sel._get_mail_description()
                mail = sel.env['mail.message']
                mail.create({
                    'model': 'project.task',
                    'res_id': sel.id,
                    'subject': 'New Project \
                        (LocTeam): ' + sel.project_id.name,
                    'author_id': self.env.user.partner_id.id,
                    'partner_ids': [(6, 0, [sel.user_id.partner_id.id])],
                    'body': body,
                    'message_type': 'comment'
                })

    def _get_mail_description(self):
        body = ''
        if self.description:
            body += self.description + """<br/>"""
            if self.env.user.signature:
                body += self.env.user.signature
        else:
            raise ValidationError(
             _('Task %s must have description!')
             % (self.name)
            )
