# -*- coding: utf-8 -*-
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import models, fields, api, _
from odoo.exceptions import ValidationError


class ResBank(models.Model):
    _inherit = "res.bank"

    """
    Add extra fields for the bank
    """
    aba = fields.Char(
        string=_('ABA'),
    )
    fed_wire = fields.Char(
        string=_('FED wire'),
    )

    """
    Function that checks the new fields of the bank
    """
    @api.multi
    @api.constrains('bic', 'aba', 'fed_wire', 'country')
    def _check_bic_aba_fed(self):
        sepa_countries = self.env['res.country.group'].search([
                ('name', '=', 'SEPA')
            ]).country_ids

        for sel in self:
            if sel.country.code == 'US':
                if not sel.bic and not sel.aba and not sel.fed_wire:
                    raise ValidationError(
                     _('BIC/ABA/FED mandatory if the country is United States')
                     )
            else:
                sepa_country = sepa_countries.filtered(
                    (lambda r: r.id == sel.country.id)
                )
                if not sepa_country and not sel.bic:
                    raise ValidationError(
                        _('BIC mandatory if the country is not SEPA'))
